@@ -23,3 +23,6 @@ class ZMQPublisher:
 
     def publish(self, topic: str, payload):
         self.socket.send_string(f"{topic}:{payload}")
+
+    def stop(self):
+        self.socket.close()
