@@ -9,8 +9,11 @@ class Subscriber:
     def __init__(self, ip, port):
         self.subscriber = ZMQSubscriber(ip, port)
 
-    def subscribe(self, topic, callback):
-        self.subscriber.subscribe(topic, callback)
+    def subscribe_first_time(self, topic, callback):
+        self.subscriber.subscribe_first_time(topic, callback)
+
+    def subscribe(self, topic):
+        self.subscriber.subscribe_to_different_topic(topic)
 
     def unsubscribe(self, topic):
         self.subscriber.unsubscribe(topic)
@@ -28,13 +31,16 @@ class ZMQSubscriber:
         self.bind = 'tcp://' + ip + ':' + port
         self.is_running = True
 
-    def subscribe(self, channel, callback):
+    def subscribe_first_time(self, channel, callback):
         self.socket.connect(self.bind)
         self.socket.setsockopt_string(zmq.SUBSCRIBE, channel)
         worker = threading.Thread(target=self.fetch_updates)
         worker.start()
         self.callback = callback
 
+    def subscribe_to_different_topic(self, channel):
+        self.socket.setsockopt_string(zmq.SUBSCRIBE, channel)
+
     def unsubscribe(self, channel):
         self.socket.setsockopt_string(zmq.UNSUBSCRIBE, channel)
 
@@ -42,8 +48,8 @@ class ZMQSubscriber:
         while self.is_running:
             try:
                 message_data = self.socket.recv().decode()
-                _, _, message = message_data.partition(":")
-                self.callback(json.loads(message))
+                topic_name, _, message = message_data.partition(":")
+                self.callback(json.loads(message), topic_name)
             except:
                 print("Error: the received data contains problems.")
                 traceback.print_exc()
